# The Editor’s UI Data

Namespace: `core/edit-post`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../../packages/edit-post/src/store/selectors.js) -->

<a name="getActiveGeneralSidebarName" href="#getActiveGeneralSidebarName">#</a> **getActiveGeneralSidebarName**

Returns the current active general sidebar name, or null if there is no
general sidebar active. The active general sidebar is a unique name to
identify either an editor or plugin sidebar.

Examples:

-   `edit-post/document`
-   `my-plugin/insert-image-sidebar`

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Active general sidebar name.

<a name="getActiveMetaBoxLocations" href="#getActiveMetaBoxLocations">#</a> **getActiveMetaBoxLocations**

Returns an array of active meta box locations.

_Parameters_

-   _state_ `Object`: Post editor state.

_Returns_

-   `Array<string>`: Active meta box locations.

<a name="getAllMetaBoxes" href="#getAllMetaBoxes">#</a> **getAllMetaBoxes**

Returns the list of all the available meta boxes.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: List of meta boxes.

<a name="getEditorMode" href="#getEditorMode">#</a> **getEditorMode**

Returns the current editing mode.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Editing mode.

<a name="getMetaBoxesPerLocation" href="#getMetaBoxesPerLocation">#</a> **getMetaBoxesPerLocation**

Returns the list of all the available meta boxes for a given location.

_Parameters_

-   _state_ `Object`: Global application state.
-   _location_ `string`: Meta box location to test.

_Returns_

-   `?Array`: List of meta boxes.

<a name="getPreference" href="#getPreference">#</a> **getPreference**

_Parameters_

-   _state_ `Object`: Global application state.
-   _preferenceKey_ `string`: Preference Key.
-   _defaultValue_ `*`: Default Value.

_Returns_

-   `*`: Preference Value.

<a name="getPreferences" href="#getPreferences">#</a> **getPreferences**

Returns the preferences (these preferences are persisted locally).

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Preferences Object.

<a name="hasMetaBoxes" href="#hasMetaBoxes">#</a> **hasMetaBoxes**

Returns true if the post is using Meta Boxes

_Parameters_

-   _state_ `Object`: Global application state

_Returns_

-   `boolean`: Whether there are metaboxes or not.

<a name="isEditingTemplate" href="#isEditingTemplate">#</a> **isEditingTemplate**

Returns true if the template editing mode is enabled.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether we're editing the template.

<a name="isEditorPanelEnabled" href="#isEditorPanelEnabled">#</a> **isEditorPanelEnabled**

Returns true if the given panel is enabled, or false otherwise. Panels are
enabled by default.

_Parameters_

-   _state_ `Object`: Global application state.
-   _panelName_ `string`: A string that identifies the panel.

_Returns_

-   `boolean`: Whether or not the panel is enabled.

<a name="isEditorPanelOpened" href="#isEditorPanelOpened">#</a> **isEditorPanelOpened**

Returns true if the given panel is open, or false otherwise. Panels are
closed by default.

_Parameters_

-   _state_ `Object`: Global application state.
-   _panelName_ `string`: A string that identifies the panel.

_Returns_

-   `boolean`: Whether or not the panel is open.

<a name="isEditorPanelRemoved" href="#isEditorPanelRemoved">#</a> **isEditorPanelRemoved**

Returns true if the given panel was programmatically removed, or false otherwise.
All panels are not removed by default.

_Parameters_

-   _state_ `Object`: Global application state.
-   _panelName_ `string`: A string that identifies the panel.

_Returns_

-   `boolean`: Whether or not the panel is removed.

<a name="isEditorSidebarOpened" href="#isEditorSidebarOpened">#</a> **isEditorSidebarOpened**

Returns true if the editor sidebar is opened.

_Parameters_

-   _state_ `Object`: Global application state

_Returns_

-   `boolean`: Whether the editor sidebar is opened.

<a name="isFeatureActive" href="#isFeatureActive">#</a> **isFeatureActive**

Returns whether the given feature is enabled or not.

_Parameters_

-   _state_ `Object`: Global application state.
-   _feature_ `string`: Feature slug.

_Returns_

-   `boolean`: Is active.

<a name="isInserterOpened" href="#isInserterOpened">#</a> **isInserterOpened**

Returns true if the inserter is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the inserter is opened.

<a name="isMetaBoxLocationActive" href="#isMetaBoxLocationActive">#</a> **isMetaBoxLocationActive**

Returns true if there is an active meta box in the given location, or false
otherwise.

_Parameters_

-   _state_ `Object`: Post editor state.
-   _location_ `string`: Meta box location to test.

_Returns_

-   `boolean`: Whether the meta box location is active.

<a name="isMetaBoxLocationVisible" href="#isMetaBoxLocationVisible">#</a> **isMetaBoxLocationVisible**

Returns true if a metabox location is active and visible

_Parameters_

-   _state_ `Object`: Post editor state.
-   _location_ `string`: Meta box location to test.

_Returns_

-   `boolean`: Whether the meta box location is active and visible.

<a name="isModalActive" href="#isModalActive">#</a> **isModalActive**

Returns true if a modal is active, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.
-   _modalName_ `string`: A string that uniquely identifies the modal.

_Returns_

-   `boolean`: Whether the modal is active.

<a name="isPluginItemPinned" href="#isPluginItemPinned">#</a> **isPluginItemPinned**

Returns true if the plugin item is pinned to the header.
When the value is not set it defaults to true.

_Parameters_

-   _state_ `Object`: Global application state.
-   _pluginName_ `string`: Plugin item name.

_Returns_

-   `boolean`: Whether the plugin item is pinned.

<a name="isPluginSidebarOpened" href="#isPluginSidebarOpened">#</a> **isPluginSidebarOpened**

Returns true if the plugin sidebar is opened.

_Parameters_

-   _state_ `Object`: Global application state

_Returns_

-   `boolean`: Whether the plugin sidebar is opened.

<a name="isPublishSidebarOpened" href="#isPublishSidebarOpened">#</a> **isPublishSidebarOpened**

Returns true if the publish sidebar is opened.

_Parameters_

-   _state_ `Object`: Global application state

_Returns_

-   `boolean`: Whether the publish sidebar is open.

<a name="isSavingMetaBoxes" href="#isSavingMetaBoxes">#</a> **isSavingMetaBoxes**

Returns true if the Meta Boxes are being saved.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the metaboxes are being saved.

<!-- END TOKEN(Autogenerated selectors|../../../../packages/edit-post/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../../packages/edit-post/src/store/actions.js) -->

<a name="closeGeneralSidebar" href="#closeGeneralSidebar">#</a> **closeGeneralSidebar**

Returns an action object signalling that the user closed the sidebar.

<a name="closeModal" href="#closeModal">#</a> **closeModal**

Returns an action object signalling that the user closed a modal.

_Returns_

-   `Object`: Action object.

<a name="closePublishSidebar" href="#closePublishSidebar">#</a> **closePublishSidebar**

Returns an action object used in signalling that the user closed the
publish sidebar.

_Returns_

-   `Object`: Action object.

<a name="hideBlockTypes" href="#hideBlockTypes">#</a> **hideBlockTypes**

Returns an action object used in signalling that block types by the given
name(s) should be hidden.

_Parameters_

-   _blockNames_ `Array<string>`: Names of block types to hide.

_Returns_

-   `Object`: Action object.

<a name="metaBoxUpdatesSuccess" href="#metaBoxUpdatesSuccess">#</a> **metaBoxUpdatesSuccess**

Returns an action object used signal a successful meta box update.

_Returns_

-   `Object`: Action object.

<a name="openGeneralSidebar" href="#openGeneralSidebar">#</a> **openGeneralSidebar**

Returns an action object used in signalling that the user opened an editor sidebar.

_Parameters_

-   _name_ `?string`: Sidebar name to be opened.

<a name="openModal" href="#openModal">#</a> **openModal**

Returns an action object used in signalling that the user opened a modal.

_Parameters_

-   _name_ `string`: A string that uniquely identifies the modal.

_Returns_

-   `Object`: Action object.

<a name="openPublishSidebar" href="#openPublishSidebar">#</a> **openPublishSidebar**

Returns an action object used in signalling that the user opened the publish
sidebar.

_Returns_

-   `Object`: Action object

<a name="removeEditorPanel" href="#removeEditorPanel">#</a> **removeEditorPanel**

Returns an action object used to remove a panel from the editor.

_Parameters_

-   _panelName_ `string`: A string that identifies the panel to remove.

_Returns_

-   `Object`: Action object.

<a name="requestMetaBoxUpdates" href="#requestMetaBoxUpdates">#</a> **requestMetaBoxUpdates**

Returns an action object used to request meta box update.

<a name="setAvailableMetaBoxesPerLocation" href="#setAvailableMetaBoxesPerLocation">#</a> **setAvailableMetaBoxesPerLocation**

Returns an action object used in signaling
what Meta boxes are available in which location.

_Parameters_

-   _metaBoxesPerLocation_ `Object`: Meta boxes per location.

<a name="setIsEditingTemplate" href="#setIsEditingTemplate">#</a> **setIsEditingTemplate**

Returns an action object used to switch to template editing.

_Parameters_

-   _value_ `boolean`: Is editing template.

_Returns_

-   `Object`: Action object.

<a name="setIsInserterOpened" href="#setIsInserterOpened">#</a> **setIsInserterOpened**

Returns an action object used to open/close the inserter.

_Parameters_

-   _value_ `boolean`: A boolean representing whether the inserter should be opened or closed.

_Returns_

-   `Object`: Action object.

<a name="showBlockTypes" href="#showBlockTypes">#</a> **showBlockTypes**

Returns an action object used in signalling that block types by the given
name(s) should be shown.

_Parameters_

-   _blockNames_ `Array<string>`: Names of block types to show.

_Returns_

-   `Object`: Action object.

<a name="switchEditorMode" href="#switchEditorMode">#</a> **switchEditorMode**

Undocumented declaration.

<a name="toggleEditorPanelEnabled" href="#toggleEditorPanelEnabled">#</a> **toggleEditorPanelEnabled**

Returns an action object used to enable or disable a panel in the editor.

_Parameters_

-   _panelName_ `string`: A string that identifies the panel to enable or disable.

_Returns_

-   `Object`: Action object.

<a name="toggleEditorPanelOpened" href="#toggleEditorPanelOpened">#</a> **toggleEditorPanelOpened**

Returns an action object used to open or close a panel in the editor.

_Parameters_

-   _panelName_ `string`: A string that identifies the panel to open or close.

_Returns_

-   `Object`: Action object.

<a name="toggleFeature" href="#toggleFeature">#</a> **toggleFeature**

Returns an action object used to toggle a feature flag.

_Parameters_

-   _feature_ `string`: Feature name.

_Returns_

-   `Object`: Action object.

<a name="togglePinnedPluginItem" href="#togglePinnedPluginItem">#</a> **togglePinnedPluginItem**

Returns an action object used to toggle a plugin name flag.

_Parameters_

-   _pluginName_ `string`: Plugin name.

_Returns_

-   `Object`: Action object.

<a name="togglePublishSidebar" href="#togglePublishSidebar">#</a> **togglePublishSidebar**

Returns an action object used in signalling that the user toggles the publish sidebar.

_Returns_

-   `Object`: Action object

<a name="updatePreferredStyleVariations" href="#updatePreferredStyleVariations">#</a> **updatePreferredStyleVariations**

Returns an action object used in signaling that a style should be auto-applied when a block is created.

_Parameters_

-   _blockName_ `string`: Name of the block.
-   _blockStyle_ `?string`: Name of the style that should be auto applied. If undefined, the "auto apply" setting of the block is removed.

_Returns_

-   `Object`: Action object.


<!-- END TOKEN(Autogenerated actions|../../../../packages/edit-post/src/store/actions.js) -->
