# Data Controls

The data controls module is a module intended to simplify implementation of common controls used with the [`@wordpress/data`](/packages/data/README.md) package.

**Note:** It is assumed that the registry being used has the controls plugin enabled on it (see [more details on controls here](https://github.com/WordPress/gutenberg/tree/master/packages/data#controls))

## Installation

Install the module

```bash
npm install @wordpress/data-controls --save
```

 _This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for ES2015+ such as lower versions of IE then using [core-js](https://github.com/zloirock/core-js) or [@babel/polyfill](https://babeljs.io/docs/en/next/babel-polyfill) will add support for these methods. Learn more about it in [Babel docs](https://babeljs.io/docs/en/next/caveats)._

The following controls are available on the object returned by the module:

## API

<!-- START TOKEN(Autogenerated API docs) -->

<a name="apiFetch" href="#apiFetch">#</a> **apiFetch**

Dispatches a control action for triggering an api fetch call.

_Usage_

```js
import { apiFetch } from '@wordpress/data-controls';

// Action generator using apiFetch
export function* myAction() {
	const path = '/v2/my-api/items';
	const items = yield apiFetch( { path } );
	// do something with the items.
}
```

_Parameters_

-   _request_ `Object`: Arguments for the fetch request.

_Returns_

-   `Object`: The control descriptor.

<a name="controls" href="#controls">#</a> **controls**

The default export is what you use to register the controls with your custom
store.

_Usage_

```js
// WordPress dependencies
import { controls } from '@wordpress/data-controls';
import { registerStore } from '@wordpress/data';

// Internal dependencies
import reducer from './reducer';
import * as selectors from './selectors';
import * as actions from './actions';
import * as resolvers from './resolvers';

registerStore( 'my-custom-store', {
reducer,
controls,
actions,
selectors,
resolvers,
} );
```

_Parameters_

-   _paths_ (unknown type): 

_Returns_

-   `Object`: An object for registering the default controls with the store.

<a name="dispatch" href="#dispatch">#</a> **dispatch**

Control for dispatching an action in a registered data store.
Alias for the `dispatch` control in the `@wordpress/data` package.

_Parameters_

-   _args_ `Array`: Arguments passed without change to the `@wordpress/data` control.

<a name="select" href="#select">#</a> **select**

Control for resolving a selector in a registered data store.
Alias for the `resolveSelect` built-in control in the `@wordpress/data` package.

_Parameters_

-   _args_ `Array`: Arguments passed without change to the `@wordpress/data` control.

<a name="syncSelect" href="#syncSelect">#</a> **syncSelect**

Control for calling a selector in a registered data store.
Alias for the `select` built-in control in the `@wordpress/data` package.

_Parameters_

-   _args_ `Array`: Arguments passed without change to the `@wordpress/data` control.


<!-- END TOKEN(Autogenerated API docs) -->
