# E2E Test Utils

End-To-End (E2E) test utils for WordPress.

_It works properly with the minimum version of Gutenberg `5.6.0` or the minimum version of WordPress `5.2.0`._

## Installation

Install the module

```bash
npm install @wordpress/e2e-test-utils --save-dev
```

## API

<!-- START TOKEN(Autogenerated API docs) -->

<a name="activatePlugin" href="#activatePlugin">#</a> **activatePlugin**

Activates an installed plugin.

_Parameters_

-   _slug_ `string`: Plugin slug.

<a name="activateTheme" href="#activateTheme">#</a> **activateTheme**

Activates an installed theme.

_Parameters_

-   _slug_ `string`: Theme slug.

<a name="arePrePublishChecksEnabled" href="#arePrePublishChecksEnabled">#</a> **arePrePublishChecksEnabled**

Verifies if publish checks are enabled.

_Returns_

-   `Promise<boolean>`: Boolean which represents the state of prepublish checks.

<a name="clearLocalStorage" href="#clearLocalStorage">#</a> **clearLocalStorage**

Clears the local storage.

<a name="clickBlockAppender" href="#clickBlockAppender">#</a> **clickBlockAppender**

Clicks the default block appender.

<a name="clickBlockToolbarButton" href="#clickBlockToolbarButton">#</a> **clickBlockToolbarButton**

Clicks a block toolbar button.

_Parameters_

-   _label_ `string`: The text string of the button label.
-   _type_ `[string]`: The type of button label: 'ariaLabel' or 'content'.

<a name="clickButton" href="#clickButton">#</a> **clickButton**

Clicks a button based on the text on the button.

_Parameters_

-   _buttonText_ `string`: The text that appears on the button to click.

<a name="clickMenuItem" href="#clickMenuItem">#</a> **clickMenuItem**

Searches for an item in the menu with the text provided and clicks it.

_Parameters_

-   _label_ `string`: The label to search the menu item for.

<a name="clickOnCloseModalButton" href="#clickOnCloseModalButton">#</a> **clickOnCloseModalButton**

Click on the close button of an open modal.

_Parameters_

-   _modalClassName_ `?string`: Class name for the modal to close

<a name="clickOnMoreMenuItem" href="#clickOnMoreMenuItem">#</a> **clickOnMoreMenuItem**

Clicks on More Menu item, searches for the button with the text provided and clicks it.

_Parameters_

-   _buttonLabel_ `string`: The label to search the button for.

<a name="closeGlobalBlockInserter" href="#closeGlobalBlockInserter">#</a> **closeGlobalBlockInserter**

Undocumented declaration.

<a name="createEmbeddingMatcher" href="#createEmbeddingMatcher">#</a> **createEmbeddingMatcher**

Creates a function to determine if a request is embedding a certain URL.

_Parameters_

-   _url_ `string`: The URL to check against a request.

_Returns_

-   `Function`: Function that determines if a request is for the embed API, embedding a specific URL.

<a name="createJSONResponse" href="#createJSONResponse">#</a> **createJSONResponse**

Respond to a request with a JSON response.

_Parameters_

-   _mockResponse_ `string`: The mock object to wrap in a JSON response.

_Returns_

-   `Promise`: Promise that responds to a request with the mock JSON response.

<a name="createNewPost" href="#createNewPost">#</a> **createNewPost**

Creates new post.

_Parameters_

-   _object_ `Object`: Object to create new post, along with tips enabling option.
-   _object.postType_ `[string]`: Post type of the new post.
-   _object.title_ `[string]`: Title of the new post.
-   _object.content_ `[string]`: Content of the new post.
-   _object.excerpt_ `[string]`: Excerpt of the new post.
-   _object.showWelcomeGuide_ `[boolean]`: Whether to show the welcome guide.

<a name="createURL" href="#createURL">#</a> **createURL**

Creates new URL by parsing base URL, WPPath and query string.

_Parameters_

-   _WPPath_ `string`: String to be serialized as pathname.
-   _query_ `?string`: String to be serialized as query portion of URL.

_Returns_

-   `string`: String which represents full URL.

<a name="createURLMatcher" href="#createURLMatcher">#</a> **createURLMatcher**

Creates a function to determine if a request is calling a URL with the substring present.

_Parameters_

-   _substring_ `string`: The substring to check for.

_Returns_

-   `Function`: Function that determines if a request's URL contains substring.

<a name="deactivatePlugin" href="#deactivatePlugin">#</a> **deactivatePlugin**

Deactivates an active plugin.

_Parameters_

-   _slug_ `string`: Plugin slug.

<a name="deleteTheme" href="#deleteTheme">#</a> **deleteTheme**

Deletes a theme from the site, activating another theme if necessary.

_Parameters_

-   _slug_ `string`: Theme slug.
-   _settings_ `?Object`: Optional settings object.
-   _settings.newThemeSlug_ `?string`: A theme to switch to if the theme to delete is active. Required if the theme to delete is active.
-   _settings.newThemeSearchTerm_ `?string`: A search term to use if the new theme is not findable by its slug.

<a name="disableFocusLossObservation" href="#disableFocusLossObservation">#</a> **disableFocusLossObservation**

Removes the focus loss listener that `enableFocusLossObservation()` adds.

<a name="disablePrePublishChecks" href="#disablePrePublishChecks">#</a> **disablePrePublishChecks**

Disables Pre-publish checks.

<a name="dragAndResize" href="#dragAndResize">#</a> **dragAndResize**

Clicks an element, drags a particular distance and releases the mouse button.

_Parameters_

-   _element_ `Object`: The puppeteer element handle.
-   _delta_ `Object`: Object containing movement distances.
-   _delta.x_ `number`: Horizontal distance to drag.
-   _delta.y_ `number`: Vertical distance to drag.

_Returns_

-   `Promise`: Promise resolving when drag completes.

<a name="enableFocusLossObservation" href="#enableFocusLossObservation">#</a> **enableFocusLossObservation**

Adds an event listener to the document which throws an error if there is a
loss of focus.

<a name="enablePageDialogAccept" href="#enablePageDialogAccept">#</a> **enablePageDialogAccept**

Enables even listener which accepts a page dialog which
may appear when navigating away from Gutenberg.

<a name="enablePrePublishChecks" href="#enablePrePublishChecks">#</a> **enablePrePublishChecks**

Enables Pre-publish checks.

<a name="ensureSidebarOpened" href="#ensureSidebarOpened">#</a> **ensureSidebarOpened**

Verifies that the edit post sidebar is opened, and if it is not, opens it.

_Returns_

-   `Promise`: Promise resolving once the edit post sidebar is opened.

<a name="findSidebarPanelToggleButtonWithTitle" href="#findSidebarPanelToggleButtonWithTitle">#</a> **findSidebarPanelToggleButtonWithTitle**

Finds a sidebar panel with the provided title.

_Parameters_

-   _panelTitle_ `string`: The name of sidebar panel.

_Returns_

-   `?ElementHandle`: Object that represents an in-page DOM element.

<a name="findSidebarPanelWithTitle" href="#findSidebarPanelWithTitle">#</a> **findSidebarPanelWithTitle**

Finds the button responsible for toggling the sidebar panel with the provided title.

_Parameters_

-   _panelTitle_ `string`: The name of sidebar panel.

_Returns_

-   `Promise<(ElementHandle|undefined)>`: Object that represents an in-page DOM element.

<a name="getAllBlockInserterItemTitles" href="#getAllBlockInserterItemTitles">#</a> **getAllBlockInserterItemTitles**

Returns an array of strings with all inserter item titles.

_Returns_

-   `Promise`: Promise resolving with an array containing all inserter item titles.

<a name="getAllBlocks" href="#getAllBlocks">#</a> **getAllBlocks**

Returns an array with all blocks; Equivalent to calling wp.data.select( 'core/block-editor' ).getBlocks();

_Returns_

-   `Promise`: Promise resolving with an array containing all blocks in the document.

<a name="getAvailableBlockTransforms" href="#getAvailableBlockTransforms">#</a> **getAvailableBlockTransforms**

Returns an array of strings with all block titles,
that the current selected block can be transformed into.

_Returns_

-   `Promise`: Promise resolving with an array containing all possible block transforms

<a name="getBlockSetting" href="#getBlockSetting">#</a> **getBlockSetting**

Returns a string containing the block title associated with the provided block name.

_Parameters_

-   _blockName_ `string`: Block name.
-   _setting_ `string`: Block setting e.g: title, attributes....

_Returns_

-   `Promise`: Promise resolving with a string containing the block title.

<a name="getCurrentPostContent" href="#getCurrentPostContent">#</a> **getCurrentPostContent**

Returns a promise which resolves with the current post content (HTML string).

_Returns_

-   `Promise`: Promise resolving with current post content markup.

<a name="getEditedPostContent" href="#getEditedPostContent">#</a> **getEditedPostContent**

Returns a promise which resolves with the edited post content (HTML string).

_Returns_

-   `Promise`: Promise resolving with post content markup.

<a name="getPageError" href="#getPageError">#</a> **getPageError**

Returns a promise resolving to one of either a string or null. A string will
be resolved if an error message is present in the contents of the page. If no
error is present, a null value will be resolved instead. This requires the
environment be configured to display errors.

_Related_

-   <http://php.net/manual/en/function.error-reporting.php>

_Returns_

-   `Promise<?string>`: Promise resolving to a string or null, depending whether a page error is present.

<a name="hasBlockSwitcher" href="#hasBlockSwitcher">#</a> **hasBlockSwitcher**

Returns a boolean indicating if the current selected block has a block switcher or not.

_Returns_

-   `Promise`: Promise resolving with a boolean.

<a name="insertBlock" href="#insertBlock">#</a> **insertBlock**

Opens the inserter, searches for the given term, then selects the first
result that appears. It then waits briefly for the block list to update.

_Parameters_

-   _searchTerm_ `string`: The text to search the inserter for.

<a name="insertBlockDirectoryBlock" href="#insertBlockDirectoryBlock">#</a> **insertBlockDirectoryBlock**

Opens the inserter, searches for the given block, then selects the
first result that appears from the block directory. It then waits briefly for the block list to
update.

_Parameters_

-   _searchTerm_ `string`: The text to search the inserter for.

<a name="insertPattern" href="#insertPattern">#</a> **insertPattern**

Opens the inserter, searches for the given pattern, then selects the first
result that appears. It then waits briefly for the block list to update.

_Parameters_

-   _searchTerm_ `string`: The text to search the inserter for.

<a name="insertReusableBlock" href="#insertReusableBlock">#</a> **insertReusableBlock**

Opens the inserter, searches for the given reusable block, then selects the
first result that appears. It then waits briefly for the block list to
update.

_Parameters_

-   _searchTerm_ `string`: The text to search the inserter for.

<a name="installPlugin" href="#installPlugin">#</a> **installPlugin**

Installs a plugin from the WP.org repository.

_Parameters_

-   _slug_ `string`: Plugin slug.
-   _searchTerm_ `?string`: If the plugin is not findable by its slug use an alternative term to search.

<a name="installTheme" href="#installTheme">#</a> **installTheme**

Installs a theme from the WP.org repository.

_Parameters_

-   _slug_ `string`: Theme slug.
-   _settings_ `?Object`: Optional settings object.
-   _settings.searchTerm_ `?string`: Search term to use if the theme is not findable by its slug.

<a name="isCurrentURL" href="#isCurrentURL">#</a> **isCurrentURL**

Checks if current URL is a WordPress path.

_Parameters_

-   _WPPath_ `string`: String to be serialized as pathname.
-   _query_ `?string`: String to be serialized as query portion of URL.

_Returns_

-   `boolean`: Boolean represents whether current URL is or not a WordPress path.

<a name="isInDefaultBlock" href="#isInDefaultBlock">#</a> **isInDefaultBlock**

Checks if the block that is focused is the default block.

_Returns_

-   `Promise`: Promise resolving with a boolean indicating if the focused block is the default block.

<a name="isOfflineMode" href="#isOfflineMode">#</a> **isOfflineMode**

Undocumented declaration.

<a name="isThemeInstalled" href="#isThemeInstalled">#</a> **isThemeInstalled**

Checks whether a theme exists on the site.

_Parameters_

-   _slug_ `string`: Theme slug to check.

_Returns_

-   `boolean`: Whether the theme exists.

<a name="loginUser" href="#loginUser">#</a> **loginUser**

Performs log in with specified username and password.

_Parameters_

-   _username_ `?string`: String to be used as user credential.
-   _password_ `?string`: String to be used as user credential.

<a name="mockOrTransform" href="#mockOrTransform">#</a> **mockOrTransform**

Mocks a request with the supplied mock object, or allows it to run with an optional transform, based on the
deserialised JSON response for the request.

_Parameters_

-   _mockCheck_ `Function`: function that returns true if the request should be mocked.
-   _mock_ `Object`: A mock object to wrap in a JSON response, if the request should be mocked.
-   _responseObjectTransform_ `(Function|undefined)`: An optional function that transforms the response's object before the response is used.

_Returns_

-   `Promise`: Promise that uses `mockCheck` to see if a request should be mocked with `mock`, and optionally transforms the response with `responseObjectTransform`.

<a name="openDocumentSettingsSidebar" href="#openDocumentSettingsSidebar">#</a> **openDocumentSettingsSidebar**

Clicks on the button in the header which opens Document Settings sidebar when it is closed.

<a name="openGlobalBlockInserter" href="#openGlobalBlockInserter">#</a> **openGlobalBlockInserter**

Opens the global block inserter.

<a name="openPreviewPage" href="#openPreviewPage">#</a> **openPreviewPage**

Opens the preview page of an edited post.

_Parameters_

-   _editorPage_ `Page`: puppeteer editor page.

_Returns_

-   `Page`: preview page.

<a name="openPublishPanel" href="#openPublishPanel">#</a> **openPublishPanel**

Opens the publish panel.

<a name="pressKeyTimes" href="#pressKeyTimes">#</a> **pressKeyTimes**

Presses the given keyboard key a number of times in sequence.

_Parameters_

-   _key_ `string`: Key to press.
-   _count_ `number`: Number of times to press.

<a name="pressKeyWithModifier" href="#pressKeyWithModifier">#</a> **pressKeyWithModifier**

Performs a key press with modifier (Shift, Control, Meta, Alt), where each modifier
is normalized to platform-specific modifier.

_Parameters_

-   _modifier_ `string`: Modifier key.
-   _key_ `string`: Key to press while modifier held.

<a name="publishPost" href="#publishPost">#</a> **publishPost**

Publishes the post, resolving once the request is complete (once a notice
is displayed).

_Returns_

-   `Promise`: Promise resolving when publish is complete.

<a name="publishPostWithPrePublishChecksDisabled" href="#publishPostWithPrePublishChecksDisabled">#</a> **publishPostWithPrePublishChecksDisabled**

Publishes the post without the pre-publish checks,
resolving once the request is complete (once a notice is displayed).

_Returns_

-   `Promise`: Promise resolving when publish is complete.

<a name="saveDraft" href="#saveDraft">#</a> **saveDraft**

Saves the post as a draft, resolving once the request is complete (once the
"Saved" indicator is displayed).

_Returns_

-   `Promise`: Promise resolving when draft save is complete.

<a name="searchForBlock" href="#searchForBlock">#</a> **searchForBlock**

Search for block in the global inserter

_Parameters_

-   _searchTerm_ `string`: The text to search the inserter for.

<a name="searchForPattern" href="#searchForPattern">#</a> **searchForPattern**

Search for pattern in the global inserter

_Parameters_

-   _searchTerm_ `string`: The text to search the inserter for.

<a name="searchForReusableBlock" href="#searchForReusableBlock">#</a> **searchForReusableBlock**

Search for reusable block in the global inserter.

_Parameters_

-   _searchTerm_ `string`: The text to search the inserter for.

<a name="selectBlockByClientId" href="#selectBlockByClientId">#</a> **selectBlockByClientId**

Given the clientId of a block, selects the block on the editor.

_Parameters_

-   _clientId_ `string`: Identified of the block.

<a name="setBrowserViewport" href="#setBrowserViewport">#</a> **setBrowserViewport**

Sets browser viewport to specified type.

_Parameters_

-   _viewport_ `WPViewport`: Viewport name or dimensions object to assign.

<a name="setClipboardData" href="#setClipboardData">#</a> **setClipboardData**

Sets the clipboard data that can be pasted with
`pressKeyWithModifier( 'primary', 'v' )`.

_Parameters_

-   _$1_ `Object`: Options.
-   _$1.plainText_ `string`: Plain text to set.
-   _$1.html_ `string`: HTML to set.

<a name="setPostContent" href="#setPostContent">#</a> **setPostContent**

Sets code editor content

_Parameters_

-   _content_ `string`: New code editor content.

_Returns_

-   `Promise`: Promise resolving with an array containing all blocks in the document.

<a name="setUpResponseMocking" href="#setUpResponseMocking">#</a> **setUpResponseMocking**

Sets up mock checks and responses. Accepts a list of mock settings with the following properties:

-   `match`: function to check if a request should be mocked.
-   `onRequestMatch`: async function to respond to the request.

_Usage_

```js
const MOCK_RESPONSES = [
  {
    match: isEmbedding( 'https://wordpress.org/gutenberg/handbook/' ),
    onRequestMatch: JSONResponse( MOCK_BAD_WORDPRESS_RESPONSE ),
  },
  {
    match: isEmbedding( 'https://wordpress.org/gutenberg/handbook/block-api/attributes/' ),
    onRequestMatch: JSONResponse( MOCK_EMBED_WORDPRESS_SUCCESS_RESPONSE ),
  }
];
setUpResponseMocking( MOCK_RESPONSES );
```

If none of the mock settings match the request, the request is allowed to continue.

_Parameters_

-   _mocks_ `Array`: Array of mock settings.

<a name="showBlockToolbar" href="#showBlockToolbar">#</a> **showBlockToolbar**

The block toolbar is not always visible while typing.
Call this function to reveal it.

<a name="switchEditorModeTo" href="#switchEditorModeTo">#</a> **switchEditorModeTo**

Switches editor mode.

_Parameters_

-   _mode_ `string`: String editor mode.

<a name="switchUserToAdmin" href="#switchUserToAdmin">#</a> **switchUserToAdmin**

Switches the current user to the admin user (if the user
running the test is not already the admin user).

<a name="switchUserToTest" href="#switchUserToTest">#</a> **switchUserToTest**

Switches the current user to whichever user we should be
running the tests as (if we're not already that user).

<a name="toggleGlobalBlockInserter" href="#toggleGlobalBlockInserter">#</a> **toggleGlobalBlockInserter**

Toggles the global inserter.

<a name="toggleMoreMenu" href="#toggleMoreMenu">#</a> **toggleMoreMenu**

Toggles the More Menu.

<a name="toggleOfflineMode" href="#toggleOfflineMode">#</a> **toggleOfflineMode**

Undocumented declaration.

<a name="toggleScreenOption" href="#toggleScreenOption">#</a> **toggleScreenOption**

Toggles the screen option with the given label.

_Parameters_

-   _label_ `string`: The label of the screen option, e.g. 'Show Tips'.
-   _shouldBeChecked_ `?boolean`: If true, turns the option on. If false, off. If undefined, the option will be toggled.

<a name="transformBlockTo" href="#transformBlockTo">#</a> **transformBlockTo**

Converts editor's block type.

_Parameters_

-   _name_ `string`: Block name.

<a name="trashAllPosts" href="#trashAllPosts">#</a> **trashAllPosts**

Navigates to the post listing screen and bulk-trashes any posts which exist.

_Parameters_

-   _postType_ `string`: String slug for type of post to trash.
-   _postStatus_ `string`: String status of posts to trash.

_Returns_

-   `Promise`: Promise resolving once posts have been trashed.

<a name="uninstallPlugin" href="#uninstallPlugin">#</a> **uninstallPlugin**

Uninstalls a plugin.

_Parameters_

-   _slug_ `string`: Plugin slug.

<a name="visitAdminPage" href="#visitAdminPage">#</a> **visitAdminPage**

Visits admin page; if user is not logged in then it logging in it first, then visits admin page.

_Parameters_

-   _adminPath_ `string`: String to be serialized as pathname.
-   _query_ `string`: String to be serialized as query portion of URL.

<a name="waitForWindowDimensions" href="#waitForWindowDimensions">#</a> **waitForWindowDimensions**

Function that waits until the page viewport has the required dimensions.
It is being used to address a problem where after using setViewport the execution may continue,
without the new dimensions being applied.
<https://github.com/GoogleChrome/puppeteer/issues/1751>

_Parameters_

-   _width_ `number`: Width of the window.
-   _height_ `number`: Height of the window.


<!-- END TOKEN(Autogenerated API docs) -->

<br/><br/><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
